@@ -9,7 +9,7 @@ _LEVELS = ["debug", "info", "warning", "error", "critical"]
 
 
 class UseCaseOutcome:
-    def __init__(self, host: str, access_token: str, sl: Swimlane) -> None:
+    def __init__(self, sl: Swimlane) -> None:
         self.sl = sl
         self.logs: List[Dict[str, str]] = []
         self.metrics: List[Dict[str, str]] = []
